You are viewing a plain text version of this content. The canonical link for it is here.
Posted to issues@maven.apache.org by "Enrico Olivelli (JIRA)" <ji...@apache.org> on 2018/12/27 08:29:00 UTC

[jira] [Commented] (MASSEMBLY-888) jar-with-dependencies performance can be greatly improved by using the cache

    [ https://issues.apache.org/jira/browse/MASSEMBLY-888?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=16729431#comment-16729431 ] 

Enrico Olivelli commented on MASSEMBLY-888:
-------------------------------------------

[~rbjorklin] Do you have time to test with current master (3.1.1) ?

We have updated plexus-archiver to 4.0.0.

Thank you in advance

> jar-with-dependencies performance can be greatly improved by using the cache
> ----------------------------------------------------------------------------
>
>                 Key: MASSEMBLY-888
>                 URL: https://issues.apache.org/jira/browse/MASSEMBLY-888
>             Project: Maven Assembly Plugin
>          Issue Type: Improvement
>    Affects Versions: 3.1.0
>            Reporter: Robin Björklin
>            Priority: Major
>              Labels: performance
>
> Plexus-io disabled use of URLConnection cache back in 2016 (see external issue link) which has a very noticeable performance impact when building a jar-with-dependencies and one or more of the dependencies are fairly large such as eclipse-collections. If this could be made configurable it would be great as we're seeing build times drop from ~2 minutes to ~20 seconds on single module builds.



--
This message was sent by Atlassian JIRA
(v7.6.3#76005)